#!/usr/bin/env python
# -*- coding: utf-8 -*-
# vim: ai ts=4 sts=4 et sw=4
# Written by Alan Viars - This software is public domain

import sys
from datetime import datetime

from pymongo import MongoClient
import os
import sys
import string
import json
import csv
from collections import OrderedDict
import random
from random import randint

MONGO_HOST = "127.0.0.1"
MONGO_PORT = 27017


STATUS_CHOICES = ("Y", "Y", "Y", "Y", "N")
TIN_TYPE_CHOICES = ("S", "S", "S", "S", "S", "S", "E", "E" "I")

TIN_CHOICES = ("560611570"
               "560611571",
               "560611572",
               "560611573",
               "560611574",
               "560611575")

APM_PROGRAM_NAME_CHOICES = ('SSP', 'Nextgen')


PART_B_CHOICES = ("Y", "N")


def makepecosdb(database_name="pecos", collection_name="compiled"):

    i = 0
    try:

        mc = MongoClient(host=MONGO_HOST, port=MONGO_PORT)
        db = mc[database_name]
        # Drop old collections
        try:
            db.drop_collection('compiled_individuals')
            db.drop_collection('compiled_organizations')
            db.drop_collection('compiled')
        except:
            print(sys.exc_info)
        base_collection = db['base']
        addresses_collection = db['addresses']
        reassignments_collection = db['reassignments']
        specialties_collection = db['specialties']
        compiled_individuals_collection = db['compiled_individuals']
        compiled_organizations_collection = db['compiled_organizations']
        compiled_collection = db['compiled']

        for bdoc in base_collection.find():
            i += 1
            d = OrderedDict()

            d['pecos_id'] = bdoc['PECOS_ASCT_CNTL_ID']
            d['enrollment_id'] = bdoc['ENRLMT_ID']
            d['npi'] = bdoc['NPI']

            # d['tin'] = str(randint(560611570, 560700000))

            if bdoc['ENRLMT_ID'].startswith('O'):
                d['enrollment_type'] = "O"
                d['entity_type'] = "2"
                # d['tin_type'] = random.choice(TIN_TYPE_CHOICES)
            elif bdoc['ENRLMT_ID'].startswith('I'):
                d['enrollment_type'] = "I"
                d['entity_type'] = "1"
            d['first_name'] = bdoc['FIRST_NAME']
            d['last_name'] = bdoc['LAST_NAME']
            d['organization_name'] = bdoc['ORG_NAME']

            d['apm_program_name'] = random.choice(STATUS_CHOICES)
            d['apm_entity_name'] = "Some APN Entity Name"
            d['status'] = random.choice(STATUS_CHOICES)
            # d['number_patiens_seen'] = randint(1, 999)
            # d['part_b_allowed_charges'] = randint(0, 15000)

            if bdoc['FIRST_NAME']:
                d['name'] = "%s %s" % (bdoc['FIRST_NAME'], bdoc['LAST_NAME'])
            else:
                d['name'] = bdoc['ORG_NAME']

            # d['first_approved_date'] = "2000-01-01"
            # d['last_approved_date'] = "2016-11-11"

            d['reassignments'] = []
            d['addresses'] = []
            base_specialty = OrderedDict()
            base_specialty['code'] = bdoc['PROVIDER_TYPE_CD'][3:]
            base_specialty['decription'] = bdoc["PROVIDER_TYPE_DESC"]
            d['specialties'] = [base_specialty,]
            
            
            d['addresses'] = []
            d["ad"] = "This API is powered by Djmongo. http://videntity.com"

            if d['entity_type'] == "1":

                for rdoc in reassignments_collection.find(
                        {"REASGN_BNFT_ENRLMT_ID": bdoc['ENRLMT_ID']}):

                    ac = base_collection.find(
                        {'ENRLMT_ID': rdoc["RCV_BNFT_ENRLMT_ID"]})

                    for a in ac:
                        reassigned_to = OrderedDict()

                        if a['FIRST_NAME']:
                            reassigned_to['name'] = "%s %s" % (
                                a['FIRST_NAME'], a['LAST_NAME'])
                        else:
                            reassigned_to['name'] = a['ORG_NAME']
                        reassigned_to['pecos_id'] = a['PECOS_ASCT_CNTL_ID']
                        reassigned_to['npi'] = a['NPI']
                        reassigned_to['enrollment_id'] = a['ENRLMT_ID']
                        reassigned_to['tin'] = "SCRUBBED"
                        reassigned_to['tin_type'] = ""

                        if str(a['ENRLMT_ID']).startswith("O"):

                            reassigned_to['entity_type'] = "2"
                        else:
                            reassigned_to['entity_type'] = "1"

                        d["reassignments"].append(
                            {"reassigned_to": reassigned_to, "effective_date": "1980-01-01"})

            elif d['entity_type'] == "2":
                for rdoc in reassignments_collection.find(
                        {"RCV_BNFT_ENRLMT_ID": bdoc['ENRLMT_ID']}):

                    ac = base_collection.find(
                        {'ENRLMT_ID': rdoc["REASGN_BNFT_ENRLMT_ID"]})
                    for a in ac:
                        assignee = OrderedDict()
                        if a['FIRST_NAME']:
                            assignee['name'] = "%s %s" % (
                                a['FIRST_NAME'], a['LAST_NAME'])
                        else:
                            assignee['name'] = a['ORG_NAME']

                        assignee['pecos_id'] = a['PECOS_ASCT_CNTL_ID']
                        assignee['npi'] = a['NPI']
                        assignee['enrollment_id'] = a['ENRLMT_ID']
                        assignee['tin'] = "SCRUBBED"
                        assignee['tin_type'] = ""
                        if str(a['ENRLMT_ID']).startswith("O"):

                            assignee['entity_type'] = "2"
                        else:
                            assignee['entity_type'] = "1"

                        d["reassignments"].append(
                            {"assignee": assignee, "effective_date": "1980-01-01"})

            # Get addresses
            for a in addresses_collection.find(
                    {"ENRLMT_ID": bdoc['ENRLMT_ID']}):
                address = OrderedDict()
                address['address_type'] = "P"
                address['line_1'] = "123 Fake Street"
                address['line_2'] = ""
                address['city'] = a["CITY_NAME"]
                address['state'] = a["ZIP_CD"]
                address['zip_code'] = a["STATE_CD"]
                d["addresses"].append(address)

            # Get specialties
            for s in specialties_collection.find(
                    {"ENRLMT_ID": bdoc['ENRLMT_ID']}):
                specialty = OrderedDict()
                specialty['code'] = s['PROVIDER_TYPE_CD'][3:]
                specialty['decription'] = s["PROVIDER_TYPE_DESC"]
                # specialty['mips_eligible_clinician'] = random.choice(
                #   ('Y', 'N'))
                d["specialties"].append(specialty)

            if i % 1000 == 0:
                print(i)
            # print json.dumps(d, indent =4)
            compiled_collection.insert(d)

        # Walk through base

    except:
        print(sys.exc_info())
        print json.dumps(d, indent=4)

    print(i, "Processed")


if __name__ == "__main__":

    if len(sys.argv) != 2:
        print("Usage:")
        print("makepecosdocs.py [DB NAME]")
        sys.exit(1)

    database_name = sys.argv[1]
    # Run it
    makepecosdb(database_name)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# vim: ai ts=4 sts=4 et sw=4

# Written by Alan Viars
import json
import sys
import datetime
import re


def validate_direct_address_list(l, enumeration_type):
    errors = []

    # define a max_length dict
    max_values = {'organization': 150,
                  'email': 150
                  }

    # Test for max_length errors
    i = 0
    for d in l:

        for k in max_values.keys():
            if d.get(k):
                if max_values[k] < len(str(d.get(k))):
                    error = "%s : %s max allowable length %s." % (
                        d.get('email'),  max_values[k])
                    errors.append(error)

        # check for required information
        if not d.get('email'):
            error = "direct_adress %s: email is required for direct ddresses." % (
                i)
            errors.append(error)

        if not d.get('is_public'):
            error = "direct_adress %s: is_public is required for direct addresses." % (
                d.get('email'))
            errors.append(error)

        if type(d.get('is_public')) != bool:
            error = "direct_adress %s: is_public must be true or false." % (
                d.get('email'))
            errors.append(error)

        if not d.get('organization'):
            error = "direct_adress %s : organization is required." % (
                d.get('email'))
            errors.append(error)
        i += 1

    return errors



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# vim: ai ts=4 sts=4 et sw=4
# Alan Viars


AFFILIATION_PURPOSE = ('HIE-EXCHANGE', 'MEDICARE-NETWORK', 'MEDICAID-NETWORK',
                       'PRIVATE-PAYER-NETWORK', 'ACO-NETWORK', 'DOMAIN',
                       'PARENT-ORGANIZATION')

AFFILIATION_DATA_TYPE = ('NPI-1', 'NPI-2', 'HPID',
                         'OEID', 'MAC', 'EIN', 'PAC-ID', 'OTHER')

ENDPOINT_DATA_TYPE = (
    'DIRECT-EMAIL-ADDRESS',
    'REGULAR-EMAIL-ADDRESS',
    'SOAP-WS-URL',
    'CONNECT-URL',
    'FHIR-URL',
    'RESTFUL-WS-URL',
    'WEBSITE-URL',
    'OTHER-URL')


SUFFIX_CHOICES = ('Jr.', 'Sr.', 'I', 'II', 'III', 'IV',
                  'V', 'VI', 'VII', 'VIII', 'IX', 'X')

PREFIX_CHOICES = ('Ms.', 'Mr.', 'Miss', 'Mrs.', 'Dr.', 'Prof.')


INDIVIDUAL_OTHER_NAME_CHOICES = ("", "1", "2", "5")

SOLE_PROPRIETOR_OTHER_NAME_CHOICES = ("", "1", "2", "3", "5")

ORGANIZATION_OTHER_NAME_CHOICES = ("", "3", "4", "5")


OTHER_NAME_CHOICES = ("", "1", "2", "3", "4", "5")


LICENSE_TYPE_CODES = ('AK-APN', 'AK-CNA', 'AK-CNM', 'AK-CNS', 'AK-DCH', 'AK-DEN',
                      'AK-DOS', 'AK-DPM',
                      'AK-DVM', 'AK-MDR', 'AK-MWF', 'AK-NPR', 'AK-ODR', 'AK-PAS', 'AK-RPH', 'AK-UNK',
                      'AL-APN', 'AL-CNA', 'AL-CNM', 'AL-CNS', 'AL-DCH', 'AL-DEN', 'AL-DOS', 'AL-DPM',
                      'AL-DVM', 'AL-MDR', 'AL-MWF', 'AL-NPR', 'AL-ODR', 'AL-PAS', 'AL-RPH', 'AL-UNK',
                      'AR-APN', 'AR-CNA', 'AR-CNM', 'AR-CNS', 'AR-DCH', 'AR-DEN', 'AR-DOS', 'AR-DPM',
                      'AR-DVM', 'AR-MDR', 'AR-MWF', 'AR-NPR', 'AR-ODR', 'AR-PAS', 'AR-RPH', 'AR-UNK',
                      'AS-UNK', 'AZ-APN', 'AZ-CNA', 'AZ-CNM', 'AZ-CNS', 'AZ-DCH', 'AZ-DEN', 'AZ-DOS',
                      'AZ-DPM', 'AZ-DVM', 'AZ-MDR', 'AZ-MWF', 'AZ-NPR', 'AZ-ODR', 'AZ-PAS', 'AZ-RPH',
                      'AZ-UNK', 'CA-APN', 'CA-CNA', 'CA-CNM', 'CA-CNS', 'CA-DCH', 'CA-DEN', 'CA-DOS',
                      'CA-DPM', 'CA-DVM', 'CA-MDR', 'CA-MWF', 'CA-NPR', 'CA-ODR', 'CA-PAS', 'CA-RPH',
                      'CA-UNK', 'CO-APN', 'CO-CNA', 'CO-CNM', 'CO-CNS', 'CO-DCH', 'CO-DEN', 'CO-DOS',
                      'CO-DPM', 'CO-DVM', 'CO-MDR', 'CO-MDU', 'CO-MWF', 'CO-NPR', 'CO-ODR', 'CO-PAS',
                      'CO-RPH', 'CO-UNK', 'CT-APN', 'CT-CNA', 'CT-CNM', 'CT-CNS', 'CT-DCH', 'CT-DEN',
                      'CT-DOS', 'CT-DPM', 'CT-DVM', 'CT-MDR', 'CT-MWF', 'CT-NPR', 'CT-ODR', 'CT-PAS',
                      'CT-RPH', 'CT-UNK', 'DC-APN', 'DC-CNA', 'DC-CNM', 'DC-CNS', 'DC-DCH', 'DC-DEN',
                      'DC-DOS', 'DC-DPM', 'DC-DVM', 'DC-MDR', 'DC-MWF', 'DC-NPR', 'DC-ODR', 'DC-PAS',
                      'DC-RPH', 'DC-UNK', 'DE-APN', 'DE-CNA', 'DE-CNM', 'DE-CNS', 'DE-DCH', 'DE-DEN',
                      'DE-DOS', 'DE-DPM', 'DE-DVM', 'DE-MDR', 'DE-MWF', 'DE-NPR', 'DE-ODR', 'DE-PAS',
                      'DE-RPH', 'DE-UNK', 'FL-APN', 'FL-CNA', 'FL-CNM', 'FL-CNS', 'FL-DCH', 'FL-DEN',
                      'FL-DOS', 'FL-DPM', 'FL-DVM', 'FL-MDR', 'FL-MWF', 'FL-NPR', 'FL-ODR', 'FL-PAS',
                      'FL-RPH', 'FL-UNK', 'FM-UNK', 'GA-APN', 'GA-CNA', 'GA-CNM', 'GA-CNS', 'GA-DCH',
                      'GA-DEN', 'GA-DOS', 'GA-DPM', 'GA-DVM', 'GA-MDR', 'GA-MWF', 'GA-NPR', 'GA-ODR',
                      'GA-PAS', 'GA-RPH', 'GA-UNK', 'GU-UNK', 'HI-APN', 'HI-CNA', 'HI-CNM', 'HI-CNS',
                      'HI-DCH', 'HI-DEN', 'HI-DOS', 'HI-DPM', 'HI-DVM', 'HI-MDR', 'HI-MWF', 'HI-NPR',
                      'HI-ODR', 'HI-PAS', 'HI-RPH', 'HI-UNK', 'IA-APN', 'IA-CNA', 'IA-CNM', 'IA-CNS',
                      'IA-DCH', 'IA-DEN', 'IA-DOS', 'IA-DPM', 'IA-DVM', 'IA-MDR', 'IA-MWF', 'IA-NPR',
                      'IA-ODR', 'IA-PAS', 'IA-RPH', 'IA-UNK', 'ID-APN', 'ID-CNA', 'ID-CNM', 'ID-CNS',
                      'ID-DCH', 'ID-DEN', 'ID-DOS', 'ID-DPM', 'ID-DVM', 'ID-MDR', 'ID-MWF', 'ID-NPR',
                      'ID-ODR', 'ID-PAS', 'ID-RPH', 'ID-UNK', 'IL-APN', 'IL-CNA', 'IL-CNM', 'IL-CNS',
                      'IL-DCH', 'IL-DEN', 'IL-DOS', 'IL-DPM', 'IL-DVM', 'IL-MDR', 'IL-MWF', 'IL-NPR',
                      'IL-ODR', 'IL-PAS', 'IL-RPH', 'IL-UNK', 'IN-APN', 'IN-CNA', 'IN-CNM', 'IN-CNS',
                      'IN-DCH', 'IN-DEN', 'IN-DOS', 'IN-DPM', 'IN-DVM', 'IN-MDR', 'IN-MWF', 'IN-NPR',
                      'IN-ODR', 'IN-PAS', 'IN-RPH', 'IN-UNK', 'KS-APN', 'KS-CNA', 'KS-CNM', 'KS-CNS',
                      'KS-DCH', 'KS-DEN', 'KS-DOS', 'KS-DPM', 'KS-DVM', 'KS-MDR', 'KS-MWF', 'KS-NPR',
                      'KS-ODR', 'KS-PAS', 'KS-RPH', 'KS-UNK', 'KY-APN', 'KY-CNA', 'KY-CNM', 'KY-CNS',
                      'KY-DCH', 'KY-DEN', 'KY-DOS', 'KY-DPM', 'KY-DVM', 'KY-MDR', 'KY-MWF', 'KY-NPR',
                      'KY-ODR', 'KY-PAS', 'KY-RPH', 'KY-UNK', 'LA-APN', 'LA-CNA', 'LA-CNM', 'LA-CNS',
                      'LA-DCH', 'LA-DEN', 'LA-DOS', 'LA-DPM', 'LA-DVM', 'LA-MDR', 'LA-MWF', 'LA-NPR',
                      'LA-ODR', 'LA-PAS', 'LA-RPH', 'LA-UNK', 'MA-APN', 'MA-CNA', 'MA-CNM', 'MA-CNS',
                      'MA-DCH', 'MA-DEN', 'MA-DOS', 'MA-DPM', 'MA-DVM', 'MA-MDR', 'MA-MWF', 'MA-NPR',
                      'MA-ODR', 'MA-PAS', 'MA-RPH', 'MA-UNK', 'MD-APN', 'MD-CNA', 'MD-CNM', 'MD-CNS',
                      'MD-DCH', 'MD-DEN', 'MD-DOS', 'MD-DPM', 'MD-DVM', 'MD-MDR', 'MD-MWF', 'MD-NPR',
                      'MD-ODR', 'MD-PAS', 'MD-RPH', 'MD-UNK', 'ME-APN', 'ME-CNA', 'ME-CNM', 'ME-CNS',
                      'ME-DCH', 'ME-DEN', 'ME-DOS', 'ME-DPM', 'ME-DVM', 'ME-MDR', 'ME-MWF', 'ME-NPR',
                      'ME-ODR', 'ME-PAS', 'ME-RPH', 'ME-UNK', 'MH-UNK', 'MI-APN', 'MI-CNA', 'MI-CNM',
                      'MI-NPR', 'MI-ODR', 'MI-PAS', 'MI-RPH', 'MI-UNK', 'MN-APN', 'MN-CNA', 'MN-CNM',
                      'MN-CNS', 'MN-DCH', 'MN-DEN', 'MN-DOS', 'MN-DPM', 'MN-DVM', 'MN-MDR', 'MN-MWF',
                      'MN-NPR', 'MN-ODR', 'MN-PAS', 'MN-RPH', 'MN-UNK', 'MO-APN', 'MO-CNA', 'MO-CNM',
                      'MO-CNS', 'MO-DCH', 'MO-DEN', 'MO-DOS', 'MO-DPM', 'MO-DVM', 'MO-MDR', 'MO-MWF',
                      'MO-NPR', 'MO-ODR', 'MO-PAS', 'MO-RPH', 'MO-UNK', 'MP-UNK', 'MS-APN', 'MS-CNA',
                      'MS-CNM', 'MS-CNS', 'MS-DCH', 'MS-DEN', 'MS-DOS', 'MS-DPM', 'MS-DVM', 'MS-MDR',
                      'MS-MWF', 'MS-NPR', 'MS-ODR', 'MS-PAS', 'MS-RPH', 'MS-UNK', 'MT-APN', 'MT-CNA',
                      'MT-CNM', 'MT-CNS', 'MT-DCH', 'MT-DEN', 'MT-DOS', 'MT-DPM', 'MT-DVM', 'MT-MDR',
                      'MT-MWF', 'MT-NPR', 'MT-ODR', 'MT-PAS', 'MT-RPH', 'MT-UNK', 'NC-APN', 'NC-CNA',
                      'NC-CNM', 'NC-CNS', 'NC-DCH', 'NC-DEN', 'NC-DOS', 'NC-DPM', 'NC-DVM', 'NC-MDR',
                      'NC-MWF', 'NC-NPR', 'NC-ODR', 'NC-PAS', 'NC-RPH', 'NC-UNK', 'ND-APN', 'ND-CNA',
                      'ND-CNM', 'ND-CNS', 'ND-DCH', 'ND-DEN', 'ND-DOS', 'ND-DPM', 'ND-DVM', 'ND-MDR',
                      'ND-MWF', 'ND-NPR', 'ND-ODR', 'ND-PAS', 'ND-RPH', 'ND-UNK', 'NE-APN', 'NE-CNA',
                      'NE-CNM', 'NE-CNS', 'NE-DCH', 'NE-DEN', 'NE-DOS', 'NE-DPM', 'NE-DVM', 'NE-MDR',
                      'NE-MWF', 'NE-NPR', 'NE-ODR', 'NE-PAS', 'NE-RPH', 'NE-UNK', 'NH-APN', 'NH-CNA',
                      'NH-CNM', 'NH-CNS', 'NH-DCH', 'NH-DEN', 'NH-DOS', 'NH-DPM', 'NH-DVM', 'NH-MDR',
                      'NH-MWF', 'NH-NPR', 'NH-ODR', 'NH-PAS', 'NH-RPH', 'NH-UNK', 'NJ-APN', 'NJ-CNA',
                      'NJ-CNM', 'NJ-CNS', 'NJ-DCH', 'NJ-DEN', 'NJ-DOS', 'NJ-DPM', 'NJ-DVM', 'NJ-MDR',
                      'NJ-MWF', 'NJ-NPR', 'NJ-ODR', 'NJ-PAS', 'NJ-RPH', 'NJ-UNK', 'NM-APN', 'NM-CNA',
                      'NM-CNM', 'NM-CNS', 'NM-DCH', 'NM-DEN', 'NM-DOS', 'NM-DPM', 'NM-DVM', 'NM-MDR',
                      'NM-MWF', 'NM-NPR', 'NM-ODR', 'NM-PAS', 'NM-RPH', 'NM-UNK', 'NV-APN', 'NV-CNA',
                      'NV-CNM', 'NV-CNS', 'NV-DCH', 'NV-DEN', 'NV-DOS', 'NV-DPM', 'NV-DVM', 'NV-MDR',
                      'NV-MWF', 'NV-NPR', 'NV-ODR', 'NV-PAS', 'NV-RPH', 'NV-UNK', 'NY-APN', 'NY-CNA',
                      'NY-CNM', 'NY-CNS', 'NY-DCH', 'NY-DEN', 'NY-DPM', 'NY-DVM', 'NY-MDU', 'NY-MWF',
                      'NY-NPR', 'NY-ODR', 'NY-PAS', 'NY-RPH', 'NY-UNK', 'OH-APN', 'OH-CNA', 'OH-CNM',
                      'OH-CNS', 'OH-DCH', 'OH-DEN', 'OH-DOS', 'OH-DPM', 'OH-DVM', 'OH-MDR', 'OH-MWF',
                      'OH-NPR', 'OH-ODR', 'OH-PAS', 'OH-RPH', 'OH-UNK', 'OK-APN', 'OK-CNA', 'OK-CNM',
                      'OK-CNS', 'OK-DCH', 'OK-DEN', 'OK-DOS', 'OK-DPM', 'OK-DVM', 'OK-MDR', 'OK-MWF',
                      'OK-NPR', 'OK-ODR', 'OK-PAS', 'OK-RPH', 'OK-UNK', 'OR-APN', 'OR-CNA', 'OR-CNM',
                      'OR-CNS', 'OR-DCH', 'OR-DEN', 'OR-DOS', 'OR-DPM', 'OR-DVM', 'OR-MDR', 'OR-MWF',
                      'OR-NPR', 'OR-ODR', 'OR-PAS', 'OR-RPH', 'OR-UNK', 'PA-APN', 'PA-CNA', 'PA-CNM',
                      'PA-CNS', 'PA-DCH', 'PA-DEN', 'PA-DOS', 'PA-DPM', 'PA-DVM', 'PA-MDR', 'PA-MWF',
                      'PA-NPR', 'PA-ODR', 'PA-PAS', 'PA-RPH', 'PA-UNK', 'PR-APN', 'PR-CNA', 'PR-CNM',
                      'PR-CNS', 'PR-DCH', 'PR-DEN', 'PR-DPM', 'PR-DVM', 'PR-MDU', 'PR-MWF', 'PR-NPR',
                      'PR-ODR', 'PR-PAS', 'PR-RPH', 'PR-UNK', 'PW-UNK', 'RI-APN', 'RI-CNA', 'RI-CNM',
                      'RI-CNS', 'RI-DCH', 'RI-DEN', 'RI-DOS', 'RI-DPM', 'RI-DVM', 'RI-MDR', 'RI-MWF',
                      'RI-NPR', 'RI-ODR', 'RI-PAS', 'RI-RPH', 'RI-UNK', 'SC-APN', 'SC-CNA', 'SC-CNM',
                      'SC-CNS', 'SC-DCH', 'SC-DEN', 'SC-DOS', 'SC-DPM', 'SC-DVM', 'SC-MDR', 'SC-MWF',
                      'SC-NPR', 'SC-ODR', 'SC-PAS', 'SC-RPH', 'SC-UNK', 'SD-APN', 'SD-CNA', 'SD-CNM',
                      'SD-CNS', 'SD-DCH', 'SD-DEN', 'SD-DOS', 'SD-DPM', 'SD-DVM', 'SD-MDR', 'SD-MWF',
                      'SD-NPR', 'SD-ODR', 'SD-PAS', 'SD-RPH', 'SD-UNK', 'TN-APN', 'TN-CNA', 'TN-CNM',
                      'TN-CNS', 'TN-DCH', 'TN-DEN', 'TN-DOS', 'TN-DPM', 'TN-DVM', 'TN-MDR', 'TN-MWF',
                      'TN-NPR', 'TN-ODR', 'TN-PAS', 'TN-RPH', 'TN-UNK', 'TX-APN', 'TX-CNA', 'TX-CNM',
                      'TX-CNS', 'TX-DCH', 'TX-DEN', 'TX-DOS', 'TX-DPM', 'TX-DVM', 'TX-MDR', 'TX-MWF',
                      'TX-NPR', 'TX-ODR', 'TX-PAS', 'TX-RPH', 'TX-UNK', 'UT-APN', 'UT-CNA', 'UT-CNM',
                      'UT-CNS', 'UT-DCH', 'UT-DEN', 'UT-DOS', 'UT-DPM', 'UT-DVM', 'UT-MDR', 'UT-MWF',
                      'UT-NPR', 'UT-ODR', 'UT-PAS', 'UT-RPH', 'UT-UNK', 'VA-APN', 'VA-CNA', 'VA-CNM',
                      'VA-CNS', 'VA-DCH', 'VA-DEN', 'VA-DOS', 'VA-DPM', 'VA-DVM', 'VA-MDR', 'VA-MWF',
                      'VA-NPR', 'VA-ODR', 'VA-PAS', 'VA-RPH', 'VA-UNK', 'VI-APN', 'VI-CNA', 'VI-CNM',
                      'VI-CNS', 'VI-DCH', 'VI-DEN', 'VI-DOS', 'VI-DPM', 'VI-DVM', 'VI-MDR', 'VI-MWF',
                      'VI-NPR', 'VI-ODR', 'VI-PAS', 'VI-RPH', 'VI-UNK', 'VT-APN', 'VT-CNA', 'VT-CNM',
                      'VT-CNS', 'VT-DCH', 'VT-DEN', 'VT-DOS', 'VT-DPM', 'VT-DVM', 'VT-MDR', 'VT-MWF',
                      'VT-NPR', 'VT-ODR', 'VT-PAS', 'VT-RPH', 'VT-UNK', 'WA-APN', 'WA-CNA', 'WA-CNM',
                      'WA-CNS', 'WA-DCH', 'WA-DEN', 'WA-DOS', 'WA-DPM', 'WA-DVM', 'WA-MDR', 'WA-MWF',
                      'WA-NPR', 'WA-ODR', 'WA-PAS', 'WA-RPH', 'WA-UNK', 'WI-APN', 'WI-CNA', 'WI-CNM',
                      'WI-CNS', 'WI-DCH', 'WI-DEN', 'WI-DOS', 'WI-DPM', 'WI-DVM', 'WI-MDR', 'WI-MWF',
                      'WI-NPR', 'WI-ODR', 'WI-PAS', 'WI-RPH', 'WI-UNK', 'WV-APN', 'WV-CNA', 'WV-CNM',
                      'WV-CNS', 'WV-DCH', 'WV-DEN', 'WV-DOS', 'WV-DPM', 'WV-DVM', 'WV-MDR', 'WV-MWF',
                      'WV-NPR', 'WV-ODR', 'WV-PAS', 'WV-RPH', 'WV-UNK', 'WY-APN', 'WY-CNA', 'WY-CNM',
                      'WY-CNS', 'WY-DCH', 'WY-DEN')

ADDRESS_PURPOSE = (
    "LOCATION",
    "MAILING",
    "MEDREC-STORAGE",
    "1099",
    "REVALIDATION",
    "ADDITIONAL-LOCATION",
    "REMITTANCE",
    "TELEMEDICINE",
    "ADDITIONAL-DOCUMENTATION-REQUESTS")

ADDRESS_TYPE = ('DOM', 'MIL', 'FGN')

STATES = ('AL', 'AK', 'AZ', 'AR', 'CA', 'CO', 'CT', 'DE', 'DC', 'FL',
          'GA', 'HI', 'ID', 'IL', 'IN', 'IA', 'KS', 'KY', 'LA', 'ME',
          'MD', 'MA', 'MI', 'MN', 'MS', 'MO', 'MT', 'NE', 'NV', 'NH',
          'NJ', 'NM', 'NY', 'NC', 'ND', 'OH', 'OK', 'OR', 'PA', 'RI',
          'SC', 'SD', 'TN', 'TX', 'UT', 'VT', 'VA', 'WA', 'WV', 'WI',
          'WY', 'AS', 'FM', 'GU', 'MH', 'MP', 'PR', 'PW', 'VI', 'ZZ')

COUNTRIES = ('AF', 'AX', 'AL', 'DZ', 'AS',
             'AD', 'AO', 'AI', 'AQ', 'AG', 'AR', 'AM', 'AW', 'AU', 'AT',
             'AZ', 'BS', 'BH', 'BD', 'BB', 'BY', 'BE', 'BZ', 'BJ', 'BM',
             'BT', 'BO', 'BQ', 'BA', 'BW', 'BV', 'BR', 'IO', 'BN', 'BG',
             'BF', 'BI', 'KH', 'CM', 'CA', 'CV', 'KY', 'CF', 'TD', 'CL',
             'CN', 'CX', 'CC', 'CO', 'KM', 'CG', 'CD', 'CK', 'CR', 'CI',
             'HR', 'CU', 'CW', 'CY', 'CZ', 'DK', 'DJ', 'DM', 'DO', 'EC',
             'EG', 'SV', 'GQ', 'ER', 'EE', 'ET', 'FK', 'FO', 'FJ', 'FI',
             'FR', 'GF', 'PF', 'TF', 'GA', 'GM', 'GE', 'DE', 'GH', 'GI',
             'GR', 'GL', 'GD', 'GP', 'GU', 'GT', 'GG', 'GN', 'GW', 'GY',
             'HT', 'HM', 'VA', 'HN', 'HK', 'HU', 'IS', 'IN', 'ID', 'IR',
             'IQ', 'IE', 'IM', 'IL', 'IT', 'JM', 'JP', 'JE', 'JO', 'KZ',
             'KE', 'KI', 'KP', 'KR', 'KW', 'KG', 'LA', 'LV', 'LB', 'LS',
             'LR', 'LY', 'LI', 'LT', 'LU', 'MO', 'MK', 'MG', 'MW', 'MY',
             'MV', 'ML', 'MT', 'MH', 'MQ', 'MR', 'MU', 'YT', 'MX', 'FM',
             'MD', 'MC', 'MN', 'ME', 'MS', 'MA', 'MZ', 'MM', 'NA', 'NR',
             'NP', 'NL', 'NC', 'NZ', 'NI', 'NE', 'NG', 'NU', 'NF', 'MP',
             'NO', 'OM', 'PK', 'PW', 'PS', 'PA', 'PG', 'PY', 'PE', 'PH',
             'PN', 'PL', 'PT', 'PR', 'QA', 'RE', 'RO', 'RU', 'RW', 'BL',
             'SH', 'KN', 'LC', 'MF', 'PM', 'VC', 'WS', 'SM', 'ST', 'SA',
             'SN', 'RS', 'SC', 'SL', 'SG', 'SX', 'SK', 'SI', 'SB', 'SO',
             'ZA', 'GS', 'SS', 'ES', 'LK', 'SD', 'SR', 'SJ', 'SZ', 'SE',
             'CH', 'SY', 'TW', 'TJ', 'TZ', 'TH', 'TL', 'TG', 'TK', 'TO',
             'TT', 'TN', 'TR', 'TM', 'TC', 'TV', 'UG', 'UA', 'AE', 'GB',
             'US', 'UM', 'UY', 'UZ', 'VU', 'VE', 'VN', 'VG', 'VI', 'WF',
             'EH', 'YE', 'ZM', 'ZW')



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# vim: ai ts=4 sts=4 et sw=4
# Written by Alan Viars - This software is public domain

import sys
import os
import sys
import string
import json
import csv
import pprint
from datetime import datetime
from pymongo import MongoClient
from collections import OrderedDict


MONGO_HOST = "127.0.0.1"
MONGO_PORT = 27017


def make_pecos_nppes_fhir_docs(database_name="pecos"):

    i = 0
    try:

        mc = MongoClient(host=MONGO_HOST, port=MONGO_PORT)
        db = mc[database_name]
        fhir_organization = db['fhir_organization']
        addresses = db['addresses']
        base_pecos = db['base']
        compiled_organizations_collection = db['compiled_organizations']

        for bdoc in fhir_organization.find():
            #Counter for display

            i += 1
    # ----------------------------------------------------
    # INCORPORATE ADDRESSES and other ID's
    # ----------------------------------------------------
            try:
                match_bases = base_pecos.find({'NPI': bdoc['identifier'][0]['value']})
            except KeyError:
                continue
            m_addresses = []
            identifiers = []
            for matches in match_bases:
                try:
                    match_addresses = addresses.find({'ENRLMT_ID': matches['ENRLMT_ID']})
                except KeyError:
                    continue
                for ma in match_addresses:
                    # Create fhir address from pecos addresses
                    address = OrderedDict()
                    address['use'] = 'work'
                    address['postalCode'] = ma['ZIP_CD']
                    address['city'] = ma['CITY_NAME']
                    address['country'] = 'USA'
                    address['state'] = ma['STATE_CD']
                    # I don't think that text is exactly meant for this purpose, but
                    # we're using it here for now.
                    address['text'] = 'PECOS data practice location'
                    # Append address and remove duplicates
                    if address not in m_addresses:
                        m_addresses.append(address)

                # Other Identifiers: ENRLMT_ID, PECOS_ASCT_CNTL_ID
                enrlmt_id = OrderedDict()
                enrlmt_id['use'] = 'official'
                enrlmt_id_cc = OrderedDict()
                enrlmt_id_cc['text'] = 'Enrollment ID in PECOS basic data set'
                enrlmt_id['type'] = enrlmt_id_cc
                enrlmt_id['system'] = 'https://data.cms.gov/public-provider-enrollment'
                enrlmt_id['value'] = matches['ENRLMT_ID']
                if enrlmt_id not in identifiers:
                    identifiers.append(enrlmt_id)

                # PECOS_ASCT_CNTL_ID
                pecosAsctCntlId = OrderedDict()
                pecosAsctCntlId['use'] = 'official'
                pecosAsctCntlId_cc = OrderedDict()
                pecosAsctCntlId_cc['text'] = 'PECOS_ASCT_CNTL_ID in PECOS basic data set'
                pecosAsctCntlId['type'] = pecosAsctCntlId_cc
                pecosAsctCntlId['system'] = 'https://data.cms.gov/public-provider-enrollment'
                pecosAsctCntlId['value'] = matches['PECOS_ASCT_CNTL_ID']
                if pecosAsctCntlId not in identifiers:
                    identifiers.append(pecosAsctCntlId)
    # --------------------------------------------------------------
    # INCORPORATE AFFILIATIONS
    # --------------------------------------------------------------
            # Match up npi numbers between pecos and nppes
            try:
                match_compiled_organizations = compiled_organizations_collection.find(
                    {'NPI': bdoc['identifier'][0]['value']})
            except KeyError:
                continue
            extensions = []
            for mco in match_compiled_organizations:
                try:
                    # Create Codings
                    npi_coding = OrderedDict()
                    npi_coding['system'] = 'https://nppes.cms.hhs.gov/NPPES/Welcome.do'
                    npi_coding['code'] = mco['has_providers'][0]['NPI']
                    npi_coding['display'] = 'NPI number of affiliation'
                    # Leaving off the 'userSelected' category for now.

                    enrollmentid_coding = OrderedDict()
                    enrollmentid_coding['system'] = 'https://data.cms.gov/public-provider-enrollment'
                    enrollmentid_coding['code'] = mco['has_providers'][0]['ENRLMT_ID']
                    enrollmentid_coding['display'] = 'PECOS Enrollment ID of affiliation'

                    # Create Codeable concept
                    value_codeable_concept = OrderedDict()
                    value_codeable_concept['coding'] = [npi_coding, enrollmentid_coding]
                    value_codeable_concept['text'] = mco['has_providers'][0]['NAME'] + ', ' + mco['has_providers'][0]['DESCRIPTION']

                    # Create fhir affiliation from compiled_individuals
                    affiliation = OrderedDict()
                    affiliation['url'] = 'https://data.cms.gov/public-provider-enrollment'
                    # print(value_codeable_concept['text'])
                    affiliation['valueCodeableConcept'] = value_codeable_concept
                    # wrap in list, and remove duplicates
                    if affiliation not in extensions:
                        extensions.append(affiliation)
                except KeyError:
                    continue



            fhir_organization.update_one({"_id":bdoc['_id']}, {"$pushAll": {"extension": extensions, "address": m_addresses, "identifier": identifiers}}, upsert=True)
            # if d['resourceType'] == "Organization":
            #     compiled_organizations_collection.insert(d)
            # elif d['resourceType'] == "Practitioner":
            #     compiled_individuals_collection.insert(d)

            # print json.dumps(d, indent =4)

        # Walk through base

    except:
        print(sys.exc_info())

    print(i, "Processed")


if __name__ == "__main__":

    if len(sys.argv) != 2:
        print("Usage:")
        print("make_pecos_nppes_org_fhir.py [DATABASE NAME]")
        sys.exit(1)

    database_name = sys.argv[1]
    # Run it
    make_pecos_nppes_fhir_docs(database_name=database_name)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# vim: ai ts=4 sts=4 et sw=4
# Alan Viars

import os
import sys
import string
import json
import csv
from collections import OrderedDict


def csv2mlvs(csvfile, output_dir="output"):
    """Return a response_dict with summary of csv2mlvs transaction."""

    response_dict = OrderedDict()
    print("Start the conversion of", csvfile,
          "into the MLVS into the directory ", output_dir, ".")

    # open the csv file.
    csvhandle = csv.reader(open(csvfile, 'rb'), delimiter=',')

    rowindex = 0

    error_list = []

    try:
        os.mkdir(output_dir)
        print("Output directory", output_dir, "created.")
    except:
        print("Output directory", output_dir, "already exists.")

    for row in csvhandle:

        if rowindex == 0:
            column_headers = row
            cleaned_headers = []
            for c in column_headers:
                c = c.replace(".", "")
                c = c.replace("(", "")
                c = c.replace(")", "")
                c = c.replace("$", "-")
                c = c.replace(" ", "_")
                cleaned_headers.append(c)
        else:

            record = dict(list(zip(cleaned_headers, row)))

            # create the state dir if not already created
            state_dir = os.path.join(output_dir, record["state"])
            try:
                os.mkdir(state_dir)
                print("State directory", state_dir, "created.")
            except:
                pass

            # create the license_type dir if not already created
            lt_dir = os.path.join(state_dir, record["license_type"])
            try:
                os.mkdir(lt_dir)
                print("License type directory", lt_dir, "created.")
            except:
                pass

            fn = "%s.json" % (record["number"])
            fp = os.path.join(lt_dir, fn)

            ofile = open(fp, 'w')
            ofile.writelines(json.dumps(record, indent=4))
            ofile.close()

        rowindex += 1

    if error_list:
        response_dict['num_files_created'] = rowindex - 1
        response_dict['num_rows_errors'] = len(error_list)
        response_dict['errors'] = error_list
        response_dict['code'] = 400
        response_dict['message'] = "Completed with errors"
    else:

        # response_dict['num_rows_imported']=mongoindex
        response_dict['num_files_created'] = rowindex - 1
        response_dict['code'] = 200
        response_dict['message'] = "Completed without errors."

    return response_dict

if __name__ == "__main__":

    if len(sys.argv) != 3:
        print("Usage:")
        print("csv2mlvs.py [CSVFILE] [OUTPUT_DIR]")
        print("See mlvs.csv in the samples directory for a sample CSV file layout.")
        sys.exit(1)

    csv_file = sys.argv[1]
    output_dir = sys.argv[2]

    result = csv2mlvs(csv_file, output_dir)

    # output the JSON transaction summary
    print(json.dumps(result, indent=4))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# vim: ai ts=4 sts=4 et sw=4
# Written by Alan Viars

import sys
import json
from luhn import verify

LUHN_PREFIX = "80840"


def verify_npi(number):
    prefixed_number = "%s%s" % (LUHN_PREFIX, number)
    return verify(prefixed_number)


if __name__ == "__main__":

    if len(sys.argv) != 2:
        print("Usage:")
        print("vnpi.py [NPI]")
        print("Example:")
        print("vnpi.py ")
        sys.exit(1)

    # Get the file from the command line
    result = verify_npi(sys.argv[1])
    jresult = {"number": sys.argv[1], "valid": result}
    print(json.dumps(jresult, indent=4))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# vim: ai ts=4 sts=4 et sw=4
# Written by Alan Viars - This software is public domain

import os
import sys
import json
import jsonschema
from jsonschema import exceptions
from collections import OrderedDict


def json_schema_check(json_schema_path, file_to_check_path):

    with open(file_to_check_path) as json_file:
        deserialized_json_file = json.load(json_file)

    with open(json_schema_path) as json_schema:
        deserialized_json_schema = json.load(json_schema)

    v = jsonschema.Draft4Validator(deserialized_json_schema)
    errors = sorted(v.iter_errors(deserialized_json_file),
                    key=lambda e: e.path)
    for error in errors:
        print(error.message)

    """JSON SCHEMA CHECK"""
    results = OrderedDict()
    if errors:
        results['errors'] = errors

    else:
        results['errors'] = []
        results[
            'results'] = "Congrats! The JSON file fits the schema. There were no errors."

    return results

if __name__ == "__main__":

    if len(sys.argv) != 3:
        print("Usage:")
        print("json_schema_check.py [JSON SCHEMA] [JSON FILE TO CHECK]")
        sys.exit(1)

    json_schema_path = sys.argv[1]
    file_to_check_path = sys.argv[2]

    result = json_schema_check(json_schema_path, file_to_check_path)
    print(json.dumps(result, indent=4))



import unittest
import os
from pdt import loadnppes


class Testloadnppes(unittest.TestCase):

    def test_loadnppes(self):
        """Run loadnppes should return results """

        csvfile = os.path.join(os.path.dirname(__file__), "fiftythousand.csv")

        # Think of a better way to test this
        # loadnppes.do_update()

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# vim: ai ts=4 sts=4 et sw=4

import os
import sys
import string
import json
import csv
from collections import OrderedDict
import functools
import time
import hashlib


def chop_taxonomy(csvfile):
    """"Chop taxonomy up into its own file. Not flattened."""
    if sys.version_info[0] < 3:
        fh = open(csvfile, 'rb')
    else:
        fh = open(csvfile, 'r', newline='', encoding='iso-8859-1')
    f = csv.reader(fh, delimiter=',')
    output_file = csvfile[:-4]
    output_file = "%s_taxonomy.csv" % (output_file)
    outputcsvfileb = open(output_file, 'wb')

    if sys.version_info >= (3, 0, 0):
        outputcsvfileb = open(output_file, 'w', newline='')
    else:
        outputcsvfileb = open(output_file, 'wb')

    csvwriterb = csv.writer(outputcsvfileb, delimiter=',',
                            quoting=csv.QUOTE_MINIMAL)
    rowindex = 0

    print("Parsing", csvfile, "to create", output_file)

    for row in f:
        t = row[0:2] + row[4:7] + row[47:48] + row[54:56] + row[58:60] + row[62:64] \
            + row[66:68] + row[70:72] + row[74:76] + row[78:80] + row[82:84] \
            + row[86:88] + row[90:92] + row[94:96] + row[98:10] \
            + row[102:104] + row[106:107]  # + row[110:111]

        csvwriterb.writerow(t)
        rowindex += 1

    print("Done. Iterated over", rowindex, "rows. ")
    fh.close()
    outputcsvfileb.close()
    return output_file


def flatten_taxonomy(csvfile):
    """"Flatten the taxonomy output file."""
    if sys.version_info[0] < 3:
        fh = open(csvfile, 'rb')
    else:
        fh = open(csvfile, 'r', newline='', encoding='iso-8859-1')
    f = csv.reader(fh, delimiter=',')
    output_file = csvfile[:-4]
    output_file = "%s_flat.csv" % (output_file)

    if sys.version_info >= (3, 0, 0):
        outputcsvfileb = open(output_file, 'w', newline='')
    else:
        outputcsvfileb = open(output_file, 'wb')

    csvwriterb = csv.writer(outputcsvfileb, delimiter=',',
                            quoting=csv.QUOTE_MINIMAL)
    rowindex = 0

    print("Parsing", csvfile, "to create", output_file)
    for row in f:
        # If header row.
        if rowindex == 0:
            column_headers = row[0:5] + \
                ["Healthcare_Provider_Taxonomy_Code", "Primary"]
            cleaned_headers = []
            for c in column_headers:
                c = c.replace(".", "")
                c = c.replace("(", "")
                c = c.replace(")", "")
                c = c.replace("$", "-")
                c = c.replace(" ", "_")
                cleaned_headers.append(c)
            csvwriterb.writerow(cleaned_headers)
            rowindex += 1
        else:
            # print "here"
            start = 5
            finish = 7
            for i in range(1, 14):

                # print "HERE", start, finish, len(row)
                flat_row = row[0:5] + row[start:finish]
                # only write the taxonomy code if the cell is not blank
                if row[start]:
                    csvwriterb.writerow(flat_row)
                start += 2
                finish += 2
                rowindex += 1
    print("Done. Iterated over", rowindex, "rows. ")
    fh.close()
    outputcsvfileb.close()
    return output_file


def chop_identifiers(csvfile):
    """"Chop identifiers up into its own file. Not flattened."""

    if sys.version_info[0] < 3:
        fh = open(csvfile, 'rb')
    else:
        fh = open(csvfile, 'r', newline='', encoding='iso-8859-1')
    f = csv.reader(fh, delimiter=',')
    output_file = csvfile[:-4]
    output_file = "%s_identifiers.csv" % (output_file)

    if sys.version_info >= (3, 0, 0):
        outputcsvfileb = open(output_file, 'w', newline='')
    else:
        outputcsvfileb = open(output_file, 'wb')

    csvwriterb = csv.writer(outputcsvfileb, delimiter=',',
                            quoting=csv.QUOTE_MINIMAL)
    rowindex = 0

    print("Parsing", csvfile, "to create", output_file)

    for row in f:
        t = row[0:2] + row[4:7] + row[107:307]

        csvwriterb.writerow(t)
        rowindex += 1

    print("Iterated over", rowindex, "rows.")
    fh.close()
    outputcsvfileb.close()
    return output_file


def flatten_identifiers(csvfile):
    """"Flatten the identifiers output file."""
    if sys.version_info[0] < 3:
        fh = open(csvfile, 'rb')
    else:
        fh = open(csvfile, 'r', newline='', encoding='iso-8859-1')
    f = csv.reader(fh, delimiter=',')
    output_file = csvfile[:-4]
    output_file = "%s_flat.csv" % (output_file)

    if sys.version_info >= (3, 0, 0):
        outputcsvfileb = open(output_file, 'w', newline='')
    else:
        outputcsvfileb = open(output_file, 'wb')

    csvwriterb = csv.writer(outputcsvfileb, delimiter=',',
                            quoting=csv.QUOTE_MINIMAL)
    rowindex = 0
    print("Parsing", csvfile, "to create", output_file)
    for row in f:
        # If header row.
        if rowindex == 0:
            column_headers = row[0:5] + \
                ["Identifier", "Type Code", "State", "Issuer"]
            cleaned_headers = []
            for c in column_headers:
                c = c.replace(".", "")
                c = c.replace("(", "")
                c = c.replace(")", "")
                c = c.replace("$", "-")
                c = c.replace(" ", "_")
                cleaned_headers.append(c)
            csvwriterb.writerow(cleaned_headers)
            rowindex += 1
        else:
            # print "here"
            start = 5
            finish = 9
            for i in range(1, 50):
                flat_row = row[0:5] + row[start:finish]
                # only write the taxonomy code if the cell is not blank
                if row[start]:
                    csvwriterb.writerow(flat_row)
                start += 4
                finish += 4
                rowindex += 1
    print("Done. Iterated over", rowindex, "rows. ")
    fh.close()
    outputcsvfileb.close()
    return output_file


def chop_licenses(csvfile):
    """Chop license up into its own file. Not flattened."""
    if sys.version_info[0] < 3:
        fh = open(csvfile, 'rb')
    else:
        fh = open(csvfile, 'r', newline='', encoding='iso-8859-1')
    f = csv.reader(fh, delimiter=',')
    output_file = csvfile[:-4]
    output_file = "%s_licenses.csv" % (output_file)

    if sys.version_info >= (3, 0, 0):
        outputcsvfileb = open(output_file, 'w', newline='')
    else:
        outputcsvfileb = open(output_file, 'wb')

    csvwriterb = csv.writer(outputcsvfileb, delimiter=',',
                            quoting=csv.QUOTE_MINIMAL)
    rowindex = 0
    print("Parsing", csvfile, "to create", output_file)

    for row in f:
        l = row[0:2] + row[4:7]  + row[48:50] + row[52:54] + row[56:58] + row[60:62] + \
            row[64:66] + row[68:70] + row[72:74] + row[76:78] + row[80:82] + \
            row[84:86] + row[88:90] + row[92:94] + row[96:98] + row[100:102] + \
            row[104:106]

        csvwriterb.writerow(l)
        rowindex += 1

    print("Done. Iterated over", rowindex, "rows. ")

    fh.close()
    outputcsvfileb.close()
    return output_file


def flatten_licenses(csvfile):
    """"Flatten the licenses output file."""
    if sys.version_info[0] < 3:
        fh = open(csvfile, 'rb')
    else:
        fh = open(csvfile, 'r', newline='', encoding='iso-8859-1')
    f = csv.reader(fh, delimiter=',')
    output_file = csvfile[:-4]
    output_file = "%s_flat.csv" % (output_file)

    if sys.version_info >= (3, 0, 0):
        outputcsvfileb = open(output_file, 'w', newline='')
    else:
        outputcsvfileb = open(output_file, 'wb')

    csvwriterb = csv.writer(outputcsvfileb, delimiter=',',
                            quoting=csv.QUOTE_MINIMAL)

    rowindex = 0

    print("Parsing", csvfile, "to create", output_file)
    for row in f:
        # If header row.
        if rowindex == 0:
            column_headers = row[0:5] + ["Number", "State"]
            cleaned_headers = []
            for c in column_headers:
                c = c.replace(".", "")
                c = c.replace("(", "")
                c = c.replace(")", "")
                c = c.replace("$", "-")
                c = c.replace(" ", "_")
                cleaned_headers.append(c)
            csvwriterb.writerow(cleaned_headers)
            rowindex += 1
        else:
            # print "here"
            start = 5
            finish = 7
            for i in range(1, 15):
                flat_row = row[0:5] + row[start:finish]
                # only write the taxonomy code if the cell is not blank
                if row[start]:
                    csvwriterb.writerow(flat_row)
                start += 2
                finish += 2
                rowindex += 1
    print("Done. Iterated over", rowindex, "rows. ")
    fh.close()
    outputcsvfileb.close()
    return output_file


def chop_other_names(csvfile):
    """Chop other names up into its own file.
    No need toflatten because only one item is in the public file
    """
    if sys.version_info[0] < 3:
        fh = open(csvfile, 'rb')
    else:
        fh = open(csvfile, 'r', newline='', encoding='iso-8859-1')
    f = csv.reader(fh, delimiter=',')
    output_file = csvfile[:-4]
    output_file = "%s_other_names.csv" % (output_file)

    if sys.version_info >= (3, 0, 0):
        outputcsvfileb = open(output_file, 'w', newline='')
    else:
        outputcsvfileb = open(output_file, 'wb')

    csvwriterb = csv.writer(outputcsvfileb, delimiter=',',
                            quoting=csv.QUOTE_MINIMAL)
    rowindex = 0
    print("Parsing", csvfile, "to create", output_file)

    for row in f:
        # only write this data if something is there.
        if row[11] or row[12] or row[13]:
            l = row[0:2] + row[4:7] + row[11:19]
            csvwriterb.writerow(l)
        rowindex += 1

    print("Done. Iterated over", rowindex, "rows.")
    fh.close()
    outputcsvfileb.close()
    return output_file


def chop_addresses(csvfile):
    """Chop addresses up into its own file. Not flattened."""
    if sys.version_info[0] < 3:
        fh = open(csvfile, 'rb')
    else:
        fh = open(csvfile, 'r', newline='', encoding='iso-8859-1')
    f = csv.reader(fh, delimiter=',')
    output_file = csvfile[:-4]
    output_file = "%s_addresses.csv" % (output_file)

    if sys.version_info >= (3, 0, 0):
        outputcsvfileb = open(output_file, 'w', newline='')
    else:
        outputcsvfileb = open(output_file, 'wb')

    csvwriterb = csv.writer(outputcsvfileb, delimiter=',',
                            quoting=csv.QUOTE_MINIMAL)
    rowindex = 0
    print("Parsing", csvfile, "to create", output_file)

    for row in f:
        l = row[0:2] + row[4:7] + row[20:36]
        csvwriterb.writerow(l)
        rowindex += 1

    print ("Done. Iterated over", rowindex, "rows.")
    fh.close()
    outputcsvfileb.close()
    return output_file


def flatten_addresses(csvfile):
    """"Flatten the addresses output file."""
    if sys.version_info[0] < 3:
        fh = open(csvfile, 'rb')
    else:
        fh = open(csvfile, 'r', newline='', encoding='iso-8859-1')
    f = csv.reader(fh, delimiter=',')
    output_file = csvfile[:-4]
    output_file = "%s_flat.csv" % (output_file)

    if sys.version_info >= (3, 0, 0):
        outputcsvfileb = open(output_file, 'w', newline='')
    else:
        outputcsvfileb = open(output_file, 'wb')

    csvwriterb = csv.writer(outputcsvfileb, delimiter=',',
                            quoting=csv.QUOTE_MINIMAL)

    rowindex = 0

    print ("Parsing", csvfile, "to create", output_file)
    for row in f:
        # If header row.
        if rowindex == 0:
            column_headers = row[0:5] + ["Address Type", "Street1", "Street2", "City", "State",
                                         "ZipCode", "CountryCode",
                                         "Telephone Number",  "Fax Number", ]

            cleaned_headers = []
            for c in column_headers:
                c = c.replace(".", "")
                c = c.replace("(", "")
                c = c.replace(")", "")
                c = c.replace("$", "-")
                c = c.replace(" ", "_")
                cleaned_headers.append(c)
            csvwriterb.writerow(cleaned_headers)
            rowindex += 1
        else:
            start = 5
            finish = 13
            flat_row = row[0:5] + ["Business_Mailing", ] + row[start:finish]
            csvwriterb.writerow(flat_row)
            rowindex += 1

            start += 8
            finish += 8
            flat_row = row[0:5] + ["Practice_Location", ] + row[start:finish]
            csvwriterb.writerow(flat_row)
            rowindex += 1

    print("Done. Iterated over", rowindex, "rows. ")
    fh.close()
    outputcsvfileb.close()
    return output_file


def chop_basic(csvfile):
    """Chop basic info into its own file."""

    if sys.version_info[0] < 3:
        fh = open(csvfile, 'rb')
    else:
        fh = open(csvfile, 'r', newline='', encoding='iso-8859-1')
    f = csv.reader(fh, delimiter=',')
    output_file = csvfile[:-4]
    output_file = "%s_basic.csv" % (output_file)

    if sys.version_info >= (3, 0, 0):
        outputcsvfileb = open(output_file, 'w', newline='')
    else:
        outputcsvfileb = open(output_file, 'wb')

    csvwriterb = csv.writer(outputcsvfileb, delimiter=',',
                            quoting=csv.QUOTE_MINIMAL)

    rowindex = 0
    """#skip the first row """
    """#next(csvfile)"""
    print("start file iteration")
    for row in f:
        csvwriterb.writerow(row[0:20] + row[36:47] + row[307:314])
        rowindex += 1

    print("Done. Iterated over", rowindex, "rows.")
    fh.close()
    outputcsvfileb.close()
    return output_file


if __name__ == "__main__":

    if len(sys.argv) < 2:
        main_file = 'test.csv'
    else:
        main_file = sys.argv[1]

    # taxonomy and flat taxonomy
    taxonomy_filename = chop_taxonomy(main_file)
    flatten_taxonomy(taxonomy_filename)

    # licenses and flat licenses
    licenses_filename = chop_licenses(main_file)
    flatten_licenses(licenses_filename)

    # identifiers and flat identifiers
    identifiers_filename = chop_identifiers(main_file)
    flatten_identifiers(identifiers_filename)

    # addresses and flat addresses
    addresses_filename = chop_addresses(main_file)
    flatten_addresses(addresses_filename)

    # chop other_names
    chop_other_names(main_file)

    # chop basic
    chop_basic(main_file)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# vim: ai ts=4 sts=4 et sw=4
# Alan Viars

from pymongo import MongoClient, ASCENDING, DESCENDING
import os
import sys
import string
import json
from collections import OrderedDict

import functools
import pymongo
import time
import hashlib

MONGO_HOST = "127.0.0.1"
MONGO_PORT = 27017


def ensure_provider_indexes(database_name, collection1, collection2, collection3,
                            host=MONGO_HOST, port=MONGO_PORT, background=True):
    """Apply suiteable indexes to pecos Base collection."""

    response_dict = OrderedDict()
    mc = MongoClient(host=host, port=port)
    db = mc[database_name]
    # PECOS Base
    try:

        collection = db[collection1]

        collection.create_index([("PROVIDER_TYPE_DESC", ASCENDING)],
                                background=background)

        collection.create_index([("ORG_NAME", ASCENDING)],
                                background=background)

        collection.create_index([("FIRST_NAME", ASCENDING)],
                                background=background)
        collection.create_index([("LAST_NAME", ASCENDING)],
                                background=background)
        collection.create_index([("NPI", ASCENDING)],
                                background=background)
        collection.create_index([("GNDR_SW", ASCENDING)],
                                background=background)
        collection.create_index([("STATE_CD", ASCENDING)],
                                background=background)
        collection.create_index([("MDL_NAME", ASCENDING)],
                                background=background)
        collection.create_index([("PROVIDER_TYPE_CD", ASCENDING)],
                                background=background)

        collection.create_index([("ENRLMT_ID", ASCENDING)],
                                background=background)

        collection.create_index([("PECOS_ASCT_CNTL_ID",
                                  ASCENDING)],
                                background=background)

        response_dict['collection1'] = collection1
        response_dict['created_indexes1'] = True
        response_dict['background1'] = background
    except:
        response_dict['collection1'] = collection1
        response_dict['code1'] = 500
        response_dict['errors1'] = [str(sys.exc_info()), ]
        response_dict['message1'] = str(sys.exc_info())

    # Reassignments

    try:
        collection = db[collection2]

        collection.create_index([("REASGN_BNFT_ENRLMT_ID", ASCENDING)],
                                background=background)

        collection.create_index([("RCV_BNFT_ENRLMT_ID", ASCENDING)],
                                background=background)

        collection.create_index([("RCV_BNFT_ENRLMT_ID", ASCENDING),
                                 ("REASGN_BNFT_ENRLMT_ID", ASCENDING)],
                                background=background)

        collection.create_index([("REASGN_BNFT_ENRLMT_ID", ASCENDING),
                                 ("RCV_BNFT_ENRLMT_ID", ASCENDING)],
                                background=background)

        response_dict['collection2'] = collection2
        response_dict['created_indexes2'] = True
        response_dict['background2'] = background
    except:
        response_dict['collection2'] = collection2
        response_dict['code2'] = 500
        response_dict['errors2'] = [str(sys.exc_info()), ]
        response_dict['message2'] = str(sys.exc_info())

    # PECOS Addresses
    try:

        collection = db[collection3]

        collection.create_index([("CITY_NAME", ASCENDING)],
                                background=background)

        collection.create_index([("STATE_CD", ASCENDING)],
                                background=background)

        # collection.create_index([("address.postalCode",     ASCENDING),
        #                          ("enumeration_type", ASCENDING),
        #                          ("addresses.city",   ASCENDING),
        #                          ("addresses.state",  ASCENDING),
        #                          ("basic.first_name", ASCENDING),
        #                          ("basic.last_name",  ASCENDING),
        #                          ("basic.organization_name", ASCENDING),
        #                          ("basic.doing_business_as", ASCENDING)
        #                          ], name="biggie",
        #                         background=background)

        collection.create_index([("ZIP_CD", ASCENDING)],
                                background=background)
        collection.create_index([("ENRLMT_ID", ASCENDING)],
                                background=background)
        collection.create_index([("id", ASCENDING)],
                                background=background)

        response_dict['collection3'] = collection3
        response_dict['created_indexes3'] = True
        response_dict['background3'] = background
    except:
        response_dict['collection3'] = collection3
        response_dict['code3'] = 500
        response_dict['errors3'] = [str(sys.exc_info()), ]
        response_dict['message3'] = str(sys.exc_info())

    return response_dict

if __name__ == "__main__":

    if len(sys.argv) != 8:
        print("Usage:")
        print("create_pecos_indexes.py [DATABASE] [PECOS BASE COLLECTION NAME] [PECOS REASSIGNMENTS COLLECTION NAME] [PECOS ADDRESSES COLLECTION NAME] [HOST] [PORT] [BACKGROUND Y/N]")
        sys.exit(1)

    database = sys.argv[1]
    collection1 = sys.argv[2]
    collection2 = sys.argv[3]
    collection3 = sys.argv[4]
    host = sys.argv[5]
    port = int(sys.argv[6])

    if sys.argv[7].lower() in ("y", "yes", "t", "true"):
        background = True
    else:
        background = False

    result = ensure_provider_indexes(
        database, collection1, collection2, collection3, host, port, background)
    print(json.dumps(result, indent=4))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# vim: ai ts=4 sts=4 et sw=4
# Alan Viars

from pymongo import MongoClient, ASCENDING, DESCENDING
import os
import sys
import string
import json
from collections import OrderedDict

import functools
import pymongo
import time
import hashlib

MONGO_HOST = "127.0.0.1"
MONGO_PORT = 27017


def ensure_provider_indexes(database_name, collection1, collection2, host=MONGO_HOST,
                            port=MONGO_PORT, background=True):
    """Apply suiteable indexes to pecos compiled collection."""
    mc = MongoClient(host=host, port=port)
    db = mc[database_name]

    response_dict = OrderedDict()
    try:

        collection = db[collection1]

        collection.create_index([("NAME", ASCENDING)],
                                background=background)

        collection.create_index([("DESCRIPTION", ASCENDING)],
                                background=background)

        collection.create_index([("NPI", ASCENDING)],
                                background=background)
        collection.create_index([("works_for.NAME", ASCENDING)],
                                background=background)
        collection.create_index([("works_for.NPI", ASCENDING)],
                                background=background)
        collection.create_index([("works_for.ENRLMT_ID", ASCENDING)],
                                background=background)
        collection.create_index([("works_for.DESCRIPTION", ASCENDING)],
                                background=background)

        response_dict['collection1'] = collection1
        response_dict['created_indexes1'] = True
        response_dict['background1'] = background
    except:
        response_dict['collection1'] = collection1
        response_dict['code1'] = 500
        response_dict['errors1'] = [str(sys.exc_info()), ]
        response_dict['message1'] = str(sys.exc_info())

    try:

        collection = db[collection2]

        collection.create_index([("NAME", ASCENDING)],
                                background=background)

        collection.create_index([("DESCRIPTION", ASCENDING)],
                                background=background)

        collection.create_index([("NPI", ASCENDING)],
                                background=background)
        collection.create_index([("has_providers.NAME", ASCENDING)],
                                background=background)
        collection.create_index([("has_providers.NPI", ASCENDING)],
                                background=background)
        collection.create_index([("has_providers.ENRLMT_ID", ASCENDING)],
                                background=background)
        collection.create_index([("has_providers.DESCRIPTION", ASCENDING)],
                                background=background)

        response_dict['collection2'] = collection2
        response_dict['created_indexes2'] = True
        response_dict['background2'] = background
    except:
        response_dict['collection2'] = collection2
        response_dict['code2'] = 500
        response_dict['errors2'] = [str(sys.exc_info()), ]
        response_dict['message2'] = str(sys.exc_info())

    return dict(response_dict)

if __name__ == "__main__":

    if len(sys.argv) != 7:
        print("Usage:")
        print("create_pecos_compiled_indexes.py [DATABASE] [PECOS COMPILED INDIVIDUALS COLLECTIONS NAME] [PECOS COMPILED ORGANIZATIONS COLLECTIONS NAME] [HOST] [PORT] [BACKGROUND Y/N]")
        sys.exit(1)

    database = sys.argv[1]
    collection1 = sys.argv[2]
    collection2 = sys.argv[3]
    host = sys.argv[4]
    port = int(sys.argv[5])

    if sys.argv[6].lower() in ("y", "yes", "t", "true"):
        background = True
    else:
        background = False

    result = ensure_provider_indexes(
        database, collection1, collection2, host, port, background)
    print(json.dumps(result, indent=4))



import os
from setuptools import setup, find_packages

with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(name="pdt",
      version="0.8.2.8",
      description="Provider Data Tools",
      long_description="""A collection of scripts and APIs for working with"""
                       """health care provider data and beyond. Many tools"""
                       """are generic utilities.""",
      author="Alan Viars",
      author_email="sales@videntity.com",
      url="https://github.com/TransparentHealth/provider-data-tools",
      download_url="https://github.com/hhsidealab/provider-data-tools/"
                   "tarball/master",
      install_requires=['validate_email', 'beautifulsoup4', 'luhn', 'jdt',
                        'jsonschema', 'six', 'ndjson'],
      packages=['pdt', 'pdt.pjson', 'tests', 'pdt.fhir_json_schema'],
      include_package_data=True,
      package_data={'tests': ['fifty_thousand.csv', 'first10.csv'],
                    'pjson': ['taxonomy-license-crosswalk.csv'],
                    'fhir_json_schema': ['Practitioner.json', 'Organization.json']},
      data_files = [('bin', ['pdt/nucc_taxonomy_201.csv',])],
      scripts=['pdt/build-cdn.sh',
               'pdt/chop_nppes_public.py',
               'pdt/combine_nppes_pecos_pract_fhir.py',
               'pdt/combine_nppes_pecos_org_fhir.py',
               'pdt/create_combined_indexes.py',
               'pdt/create_pecos_compiled_indexes.py',
               'pdt/create_pecos_indexes.py',
               'pdt/create_provider_indexes.py',
               'pdt/csv2mlvs.py',
               'pdt/csv2pjson_public.py',
               'pdt/csv2fhir_public.py',
               'pdt/json_schema_check.py',
               'pdt/json_schema_check_fhir.py',
               'pdt/loadnppes.py',
               'pdt/load_nppes_and_pecos.py',
               'pdt/load_pecos.py',
               'pdt/makepecosdocs.py',
               'pdt/pjson/validate_pjson',
               'pdt/pjson/validate_pjson_affiliations',
               'pdt/pjson/validate_pjson_dir',
               'pdt/pull_pecos.py',
               'pdt/pull_new_files_ready.py',
               'pdt/vnpi.py',
               'pdt/split_practitioners_and_organizations.py',
               ]
      )



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# vim: ai ts=4 sts=4 et sw=4

import os
import sys
import string
import json
import csv
from collections import OrderedDict
import functools
import time
import hashlib


def split_practitioners_and_organizations(csvfile, include_state_list=[]):
    """Splt the two entrity type into two files.."""

    if sys.version_info[0] < 3:
        fh = open(csvfile, 'rb')
    else:
        fh = open(csvfile, 'r', newline='', encoding='iso-8859-1')
    f = csv.reader(fh, delimiter=',')
    pract_output_file = csvfile[:-4]
    pract_output_file = "%s_practitioners.csv" % (pract_output_file)
    org_output_file = csvfile[:-4]
    org_output_file = "%s_organizations.csv" % (org_output_file)


    if sys.version_info >= (3, 0, 0):
        p_outputcsvfileb = open(pract_output_file, 'w', newline='')
    else:
        p_outputcsvfileb = open(pract_output_file, 'wb')

    if sys.version_info >= (3, 0, 0):
        o_outputcsvfileb = open(org_output_file, 'w', newline='')
    else:
        o_outputcsvfileb = open(org_output_file, 'wb')




    p_csvwriterb = csv.writer(p_outputcsvfileb, delimiter=',',
                            quoting=csv.QUOTE_MINIMAL)
    o_csvwriterb = csv.writer(o_outputcsvfileb, delimiter=',',
                            quoting=csv.QUOTE_MINIMAL)


    rowindex = 0
    """#skip the first row """
    """#next(csvfile)"""
    print("start file iteration")
    for row in f:
        if include_state_list:
            if row[23] in include_state_list or row[31] in include_state_list: 
        
                if row[1] == "1":
                    p_csvwriterb.writerow(row)
                elif row[1] == "2":
                    o_csvwriterb.writerow(row)
        else:
            if row[1] == "1":
                p_csvwriterb.writerow(row)
            elif row[1] == "2":
                o_csvwriterb.writerow(row)
        rowindex+=1
        

    print("Done. Iterated over", rowindex, "rows.")
    fh.close()
    p_outputcsvfileb.close()
    o_outputcsvfileb.close()
    


if __name__ == "__main__":

    if len(sys.argv) < 2:
        main_file = 'test.csv'
    else:
        main_file = sys.argv[1]
    
    
    if len(sys.argv) > 2:
        include_state_list = sys.argv[2:]
    else:
        include_state_list = []    
    split_practitioners_and_organizations(main_file, include_state_list)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# vim: ai ts=4 sts=4 et sw=4
# Written by Alan Viars - This software is public domain

from bs4 import BeautifulSoup
try:
    # For Python 3.0 and later
    from urllib.request import urlopen
except ImportError:
    # Fall back to Python 2's urllib2
    from urllib2 import urlopen
import re
import glob
import sys
from subprocess import call
from datetime import datetime


def do_update(process_full=True, download=True):
    try:
        months = ["Jan", "Feb", "Mar", "Apr", "May", "June", "July", "Aug",
                  "Sept", "Oct", "Nov", "Dec"]
        # Get just the html page
        html_page = urlopen("http://download.cms.gov/nppes/NPI_Files.html")
        link_prefix = "http://download.cms.gov/nppes/"

        soup = BeautifulSoup(html_page, "html.parser")
        month = ""
        year = datetime.now().year
        # get all links
        zipfilelinks = []
        for link in soup.findAll('a'):
            print(link)
            # get just zips
            if link.get('href', "").endswith(".zip"):
                zipfilelinks.append(link.get('href', ""))

        print(zipfilelinks)
        # determine full v/s weekly
        weeklylinks = []
        full_link = ""
        for link in zipfilelinks:

            for m in months:
                if link.__contains__(m):
                    full_link = link_prefix + link
                    month = m
            if link.__contains__("Report"):
                deactivation_link = link
            else:
                weeklylinks.append(link)

        # Download full file
        if process_full:

            if download:
                print("Downloading", full_link)
                call(["wget", full_link])

            # Get filename and unzip
            filename = full_link.split("/")
            zipfilename = filename[-1]
            print("Unzip", zipfilename)

            call(["unzip", zipfilename])

            # inspect the local directory for the CSV
            csv_files = glob.glob("*.csv")

            for f in csv_files:
                if f.__contains__("Header"):
                    header_file = f
                else:
                    main_file_to_import = f

            # Now import the file
            print("Import", main_file_to_import)
            # first convert to json, and fhir-json respectively
            json_output_dir = "json-output/"
            fhir_output_dir = "fhir-nppes-output/"
            call(["csv2pjson-public.py", main_file_to_import, json_output_dir])
            call(["csv2fhir_public.py", main_file_to_import, fhir_output_dir])
            # Pull PECOS Data/files
            call(["pull_pecos.py", "y", "n", "n", "n"])
    except:
        print(sys.exc_info)


if __name__ == "__main__":

    if len(sys.argv) != 3:
        print("Usage:")
        print("pull_new_files_ready.py [PROCESS_FULL Y/N] "
              "[DOWNLOAD_FROM_PUBLIC_FILE Y/N]")
        print("Example:")
        print("loadnppes.py Y Y")
        sys.exit(1)

    if sys.argv[1] in ("Y", "y", "T", True):
        process_full = True
    else:
        process_full = False

    if sys.argv[2] in ("Y", "y", "T", True):
        download = True
    else:
        download = False

    # Get the file from the command line
    do_update(process_full, download)
